TimePoint class

A timestamped value, for time-series charts.

The time is mapped to the x axis (as milliseconds since epoch until a dedicated TimeScale interprets it) and value to the y axis.

LineSeries(data: [TimePoint(DateTime(2026, 1, 1), 42.0)])
Annotations

Constructors

TimePoint(DateTime time, double value)
Creates a point at time with the given value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
Position on the time (x) axis.
final
value double
Position on the vertical (measure) axis.
final

Methods

copyWith({DateTime? time, double? value}) TimePoint
Returns a copy of this point with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override