TimePoint class
A timestamped value, for time-series charts.
The time is mapped to the x axis (as milliseconds since epoch until a
dedicated TimeScale interprets it) and value to the y axis.
LineSeries(data: [TimePoint(DateTime(2026, 1, 1), 42.0)])
- Annotations
Constructors
Properties
Methods
-
copyWith(
{DateTime? time, double? value}) → TimePoint - Returns a copy of this point with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override